# nolint start
#' @import checkmate
#' @import data.table
#' @import mlr3misc
#' @import ggplot2
#' @importFrom R6 R6Class
#' @importFrom stats as.formula predict
"_PACKAGE"
# nolint end

leanify_package()
